@@ -41,17 +41,15 @@ scoring_function_wrapper <- function( scoring_function_name, data, scoring_funct
 #'                    trt = character(N) )
 #' 
 #' data$continuous_response <- runif( min = 0, max = 20, n = N )
-#' data$trt <- sample( c('Control','Experimental'), size = N, prob = c(0.4,0.6),
-#'                     replace = TRUE )
+#' data$trt <- sample( c('Control','Experimental'), size = N, prob = c(0.4,0.6), replace = TRUE )
 #' 
 #' ## Compute mean response for all data
-#' mean_response( data )
+#' mean_response( data, scoring_function_parameters = list( y_var = 'continuous_response' ) )
 #' mean( data$continuous_response ) # Function return value should match this value
 #' 
 #' ## Compute mean response for Experimental treatment arm only
-#' mean_response( data,
-#'                scoring_function_parameters = list( trt_arm = 'Experimental' ) )
-#' 
+#' scoring_function_parameters <- list( y_var = 'continuous_response', trt_arm = 'Experimental' )
+#' mean_response( data, scoring_function_parameters = scoring_function_parameters )
 #' # Function return value should match this value
 #' mean( data$continuous_response[ data$trt == 'Experimental' ] )
 #' @export
@@ -256,76 +254,87 @@ treatment_effect <- function( data,
 }
 
 
-#' @title desirable_response_proportion
-#' @description Compute proportion of subjects that have a desirable (binary) response
-#' @details This function will compute the proportion of subjects for which
-#' the response indicates a desirable response. The response proportion can
-#' be computed for a single treatment arm only (if valued for trt_arm and trt
-#' are provided) or for all data passed to the function.
-#' @seealso link{TSDT}, \link{binary_transform}
-#' @param data data.frame containing response data
-#' @param scoring_function_parameters named list of scoring function control parameters
-#' @return Proportion of (binary) response values that have a desirable value.
-#' The desirable value is 1 if desirable_response = 'increasing' and the
-#' desirable value is 0 if desirable_response = 'decreasing'.
-#' @examples
-#' N <- 50
-#' 
-#' data <- data.frame( y = numeric(N),
-#'                     trt = character(N) )
-#' 
-#' data$y <- sample( c(0,1), size = N, prob = c(0.5,0.5), replace = TRUE )
-#' data$trt <- sample( c('Control','Experimental'), size = N, prob = c(0.4,0.6), replace = TRUE )
-#' 
-#' ## Compute desirable response proportion for all data with increasing
-#' ## desirable response (i.e. larger response value is better)
-#' desirable_response_proportion( data, list( desirable_response = 'increasing' ) )
-#' mean( data$y ) # Function return value should match this value
-#' 
-#' ## Compute desirable response proportion for Experimental treatment arm only
-#' ## with decreasing desirable response (i.e. smaller response value is better).
-#' desirable_response_proportion( data, list( trt_arm = 'Experimental',
-#'                                            desirable_response = 'decreasing' ) )
-#' @export
-desirable_response_proportion <- function( data,
-                                           scoring_function_parameters = NULL ){
+## #' @title desirable_response_proportion
+## #' @description Compute proportion of subjects that have a desirable (binary) response
+## #' @details This function will compute the proportion of subjects for which
+## #' the response indicates a desirable response. The response proportion can
+## #' be computed for a single treatment arm only (if valued for trt_arm and trt
+## #' are provided) or for all data passed to the function.
+## #' @seealso link{TSDT}, \link{binary_transform}
+## #' @param data data.frame containing response data
+## #' @param scoring_function_parameters named list of scoring function control parameters
+## #' @return Proportion of (binary) response values that have a desirable value.
+## #' The desirable value is 1 if desirable_response = 'increasing' and the
+## #' desirable value is 0 if desirable_response = 'decreasing'.
+## #' @examples
+## #' N <- 50
+## #' 
+## #' data <- data.frame( binary_response = numeric(N) )
+## #' 
+## #' data$binary_response <- sample( c(0,1), size = N, prob = c(0.3,0.7), replace = TRUE )
+## #' 
+## #' ## Compute desirable response proportion with increasing desirable response
+## #' ## (i.e. larger response value is better)
+## #' 
+## #' desirable_response_proportion( data, list( y_var = 'binary_response', desirable_response = 'increasing' ) )
+## #' mean( data$binary_response ) # Function return value should match this value
+## #'
+## #' 
+## #' ## Compute desirable response proportion for Experimental treatment arm only
+## #' ## with decreasing desirable response (i.e. smaller response value is better).
+## #'
+## #' data$trt <- sample( c('Control','Experimental'), size = N, prob = c(0.4,0.6), replace = TRUE )
+## #' 
+## #' desirable_response_proportion( data, list( y_var = 'binary_response', desirable_response = 'decreasing', trt_control = 'Control' ) )
+## #'
+## #' prop.table( table( subset( data, trt != 'Control', select = 'binary_response', drop = TRUE ) ) )
+## #' 
+## #' @export
+## desirable_response_proportion <- function( data,
+##                                            scoring_function_parameters = NULL ){
 
-  ## Create NULL placeholders to prevent NOTE in R CMD check
-  desirable_response <- NULL;rm( desirable_response )
-  trt_control <- NULL;rm( trt_control )
-  
-  if( !is.null( scoring_function_parameters ) )
-      unpack_args( scoring_function_parameters )
+##   if( !is.null( scoring_function_parameters ) )
+##       unpack_args( scoring_function_parameters )
 
-  if( is.null( desirable_response ) )
-      rm( desirable_response )
+##   response <- binary_transform( get_y( data, scoring_function_parameters ) )
+##   trt <- get_trt( data, scoring_function_parameters )
+  
+##   if( desirable_response %nin% c("increasing","decreasing") )
+##       stop( "ERROR: desirable_response must be in {increasing,decreasing}" )      
 
-  if( exists( "trt_control" ) && is.null( trt_control ) )
-      rm( trt_control )
+##   if( !is.null( trt ) && !exists( "trt_control" ) )
+##       stop( "ERROR: if a treatment variable is present in data a trt_control value must be provided in scoring_function_parameters" )
   
-  response <- binary_transform( get_y( data, scoring_function_parameters ) )
-  trt <- get_trt( data, scoring_function_parameters )
-  
-  N <- length( response )
-  
-  if( desirable_response %nin% c("increasing","decreasing") )
-      stop( "ERROR: desirable_response must be in {increasing,decreasing}" )      
-  
-  # For computing the proportion when no treatment variable is provided
-  if( !exists( "trt_var" ) ){
-    # Always count score as proportion of response values equal to 1.
-    # Do not adjust this definition for desirable_response. This will
-    # be handled by the superior_subgrous() function.
-    proportion <- length( subset( response, response == 1 ) )/N 
-  }
-  # For computing the proportion only on the treatment arm
-  else{
-    response <- subset( response, trt != trt_control )
-    response <- subset( response, response == 1 )
-    proportion <- length( response )/N 
-  } 
-  return( proportion )
-}
+##   # For computing the proportion when no treatment variable is provided
+##   #if( !exists( "trt_var" ) ){
+##   if( is.null( trt ) ){
+##     # Always count score as proportion of response values equal to 1.
+##     # Do not adjust this definition for desirable_response. This will
+##     # be handled by the superior_subgrous() function.
+
+##     N <- length( response )
+    
+##     if( desirable_response == "increasing" ){
+##       proportion <- length( subset( response, response == 1 ) )/N
+##     }else{
+##       proportion <- length( subset( response, response == 0 ) )/N
+##     }
+##   }
+##   # For computing the proportion only on the treatment arm
+##   else{
+    
+##     response <- subset( response, trt != trt_control )
+##     N <- length( response )
+    
+##     if( desirable_response == "increasing" ){
+##       response <- subset( response, response == 1 )
+##     }else{ #decreasing
+##       response <- subset( response, response == 0 )
+##     }
+##     proportion <- length( response )/N 
+##   } 
+##   return( proportion )
+## }
 
 #################################################################################
 # Scoring functions for a survival outcome: difference in median (or other      #
@@ -348,11 +357,10 @@ desirable_response_proportion <- function( data,
 #' @return A quantile of the response survival time.
 #' @examples
 #' N <- 200
-#' require( survival )
-#' df <- data.frame( y = survival::Surv( runif( min = 0, max = 20, n = N ),
-#'                             sample( c(0,1), size = N, prob = c(0.2,0.8), replace = TRUE ) ),
-#'                   trt = sample( c('Control','Experimental'), size = N,
-#'                                 prob = c(0.4,0.6), replace = TRUE ) )
+#' time <- runif( min = 0, max = 20, n = N )
+#' event <- sample( c(0,1), size = N, prob = c(0.2,0.8), replace = TRUE )
+#' trt <- sample( c('Control','Experimental'), size = N, prob = c(0.4,0.6), replace = TRUE )
+#' df <- data.frame( y = survival::Surv( time, event ), trt = trt )
 #' 
 #' ## Compute median survival time in Experimental treatment arm.
 #' ex1 <- survival_time_quantile( data = df,
@@ -365,8 +373,7 @@ desirable_response_proportion <- function( data,
 #' ## behavior is to use this variable as the treatment variable. To override
 #' ## the default behavior trt = NULL is included in scoring_function_parameters.
 #' ex2 <- survival_time_quantile( data = df,
-#'                                scoring_function_parameters = list( trt = NULL,
-#'                                                          percentile = 0.25 ) )
+#'                                scoring_function_parameters = list( trt = NULL, percentile = 0.25 ) )
 #' @export
 survival_time_quantile <- function( data,
                                     scoring_function_parameters = NULL ){ 
@@ -445,7 +452,7 @@ survival_time_quantile <- function( data,
     
     if( class( quantile__ ) != "logical" ){
       
-      if( class( quantile__ ) == "numeric" ){
+      if( is( quantile__, "numeric" ) ){
         survival_time_quantile <- quantile__
       }else{
         survival_time_quantile <- quantile__$quantile[[1]]
@@ -555,7 +562,7 @@ diff_survival_time_quantile <- function( data,
 #' Therneau, T.M.,  Grambsch, P.M., and Fleming, T.R. (1990).  Martingale-based
 #' residuals for survival models.  Biometrika, 77(1), 147-160.
 #' doi:10.1093/biomet/77.1.147.
-#' \url{http://biomet.oxfordjournals.org/content/77/1/147}
+#' \url{https://academic.oup.com/biomet/article/77/1/147/271076}
 #' @export
 mean_deviance_residuals <- function( data,
                                      scoring_function_parameters = NULL ){
